/*
 * govirt-private.h: main private header
 *
 * Copyright (C) 2012 Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * Author: Christophe Fergeau <cfergeau@redhat.com>
 */
#ifndef __OVIRT_PRIVATE_H__
#define __OVIRT_PRIVATE_H__

#include <govirt/ovirt-action-rest-call.h>
#include <govirt/ovirt-api-private.h>
#include <govirt/ovirt-cluster-private.h>
#include <govirt/ovirt-collection-private.h>
#include <govirt/ovirt-data-center-private.h>
#include <govirt/ovirt-enum-types-private.h>
#include <govirt/ovirt-host-private.h>
#include <govirt/ovirt-proxy-private.h>
#include <govirt/ovirt-resource-private.h>
#include <govirt/ovirt-resource-rest-call.h>
#include <govirt/ovirt-rest-call.h>
#include <govirt/ovirt-storage-domain-private.h>
#include <govirt/ovirt-utils.h>
#include <govirt/ovirt-vm-private.h>

#endif /* __OVIRT_PRIVATE_H__ */
